# TestCaseSyncFromTo


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**var_from** | **int** |  | 
**to** | **int** |  | 

## Example

```python
from src.client.generated.models.test_case_sync_from_to import TestCaseSyncFromTo

# TODO update the JSON string below
json = "{}"
# create an instance of TestCaseSyncFromTo from a JSON string
test_case_sync_from_to_instance = TestCaseSyncFromTo.from_json(json)
# print the JSON string representation of the object
print(TestCaseSyncFromTo.to_json())

# convert the object into a dict
test_case_sync_from_to_dict = test_case_sync_from_to_instance.to_dict()
# create an instance of TestCaseSyncFromTo from a dict
test_case_sync_from_to_from_dict = TestCaseSyncFromTo.from_dict(test_case_sync_from_to_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


